@@ -166,7 +166,7 @@ class HtmlFrame(ttk.Frame):
                 if threadname().isrunning():
                     self.url_change_func(newurl)
                     if "image" in filetype:
-                        image, error = newimage(data, "_htmlframe_img_{}_{}_".format(id(self), self.image_count), filetype)
+                        image, error = newimage(data, "_htmlframe_img_{}_{}_".format(id(self), self.image_count), filetype, self.html.image_inversion_enabled)
                         self.load_html("<img style='max-width:100%' src='replace:{}'></img".format(image))
                         self.image_count += 1
                         self.image = image
@@ -344,6 +344,17 @@ class HtmlFrame(ttk.Frame):
             self.cursor = cursor
             self.config(cursor=cursor)
 
+    def get_current_link(self, resolve=True):
+        "Convenience method for getting the url of the current hyperlink"
+        if self.get_currently_hovered_node_tag().lower() == "a": 
+            href = self.get_currently_hovered_node_attribute("href")
+            if resolve:
+                return self.resolve_url(href)
+            else:
+                return href
+        else:
+            return ""
+
     def get_currently_hovered_node_tag(self):
         "Get the tag of the HTML element the mouse pointer is currently over"
         try:
